@@ -53,10 +53,10 @@ public class PixelFormat
 		"\ngetGshift() : " + getGshift() +
 		"\ngetBshift() : " + getBshift() +
 		"\ngetAshift() : " + getAshift() +
-		"\ngetRmask() : " + getRmask() +
-		"\ngetGmask() : " + getGmask() +
-		"\ngetBmask() : " + getBmask() +
-		"\ngetAmask() : " + getAmask() +
+		"\ngetRmask() : " + Integer.toHexString(getRmask()) +
+		"\ngetGmask() : " + Integer.toHexString(getGmask()) +
+		"\ngetBmask() : " + Integer.toHexString(getBmask()) +
+		"\ngetAmask() : " + Integer.toHexString(getAmask()) +
 		"\ngetColorkey() : " + getColorkey() +
 		"\ngetAlpha() : " + getAlpha();
 	}
