@@ -6,7 +6,7 @@ import sdl4gcj.input.Mouse;
 
 public class RepeatTest implements SDLConstants
 {
-	static final String BG_IMAGE_PATH = "images/maze.bmp";
+	static final String BG_IMAGE_PATH = "images/logo.bmp";
 	static final String ICON_IMAGE_PATH = "images/icon.bmp";
 
 	public static void main(String[] args)
